@@ -118,8 +118,7 @@ sub save_script_file
 
     if ( ! $installer::globals::iswindowsbuild )
     {
-        my $localcall = "chmod 775 $newscriptfilename \>\/dev\/null 2\>\&1";
-        system($localcall);
+        chmod 0775, $newscriptfilename;
     }
     
     return $newscriptfilename;
@@ -339,8 +338,7 @@ sub tar_package
         push( @installer::globals::logfileinfo, $infoline);
     }
     
-    my $localcall = "chmod 775 $tarfilename \>\/dev\/null 2\>\&1";
-    $returnvalue = system($localcall);
+    chmod 0775, $tarfilename;
 
     return ( -s $tarfilename );
 }
@@ -422,6 +420,7 @@ sub get_installation_type
     my $type = "";
     
     if ( $installer::globals::languagepack ) { $type = "langpack"; }
+    elsif ( $installer::globals::helppack ) { $type = "helppack"; }
     else { $type = "install"; }
     
     return $type;
@@ -443,14 +442,6 @@ sub get_downloadname_language
         $languages =~ s/_en-US//;
     }
 
-    # en-US is default language and can be removed therefore
-    # for one-language installation sets
-    
-    # if ( $languages =~ /^\s*en-US\s*$/ )
-    # {
-    #	$languages = "";
-    # }	
-
     if ( length ($languages) > $installer::globals::max_lang_length )
     {
         $languages = 'multi';
@@ -467,17 +458,19 @@ sub get_downloadname_productname
 {
     my ($allvariables) = @_;
 
-    my $start = "LO";
+    my $start = "LibO";
 
-    if ( $allvariables->{'PRODUCTNAME'} eq "LibreOffice" ) { $start = "LO"; }
+    if ( $allvariables->{'PRODUCTNAME'} eq "LibreOffice" ) { $start = "LibO"; }
     
-    if ( $allvariables->{'PRODUCTNAME'} eq "LO-dev" ) { $start = "LO-Dev"; }
+    if ( $allvariables->{'PRODUCTNAME'} eq "LibO-dev" ) { $start = "LibO-Dev"; }
 
-    if (( $allvariables->{'PRODUCTNAME'} eq "LibreOffice" ) && ( $allvariables->{'POSTVERSIONEXTENSION'} eq "SDK" )) { $start = "LO-SDK"; }
+    if (( $allvariables->{'PRODUCTNAME'} eq "LibreOffice" ) && ( $allvariables->{'POSTVERSIONEXTENSION'} eq "SDK" )) { $start = "LibO-SDK"; }
 
-    if (( $allvariables->{'PRODUCTNAME'} eq "LO-dev" ) && ( $allvariables->{'POSTVERSIONEXTENSION'} eq "SDK" )) { $start = "LO-Dev-SDK"; }
+    if (( $allvariables->{'PRODUCTNAME'} eq "LibO-dev" ) && ( $allvariables->{'POSTVERSIONEXTENSION'} eq "SDK" )) { $start = "LibO-Dev-SDK"; }
     
-    if ( $allvariables->{'PRODUCTNAME'} eq "URE" ) { $start = "LO-URE"; }
+    if ( $allvariables->{'PRODUCTNAME'} eq "URE" ) { $start = "LibO-URE"; }
+
+    if ( $allvariables->{'PRODUCTNAME'} eq "OxygenOffice" ) { $start = "OOOP"; }
     
     if ( $allvariables->{'PRODUCTNAME'} eq "BrOffice.org" ) { $start = "BrOo"; }
 
@@ -592,7 +585,6 @@ sub get_download_platformname
     }
     else
     {
-        # $platformname = $installer::globals::packageformat;
         $platformname = $installer::globals::compiler;		
     }
     
@@ -657,12 +649,31 @@ sub get_install_type
     {
         $type = "langpack";
 
-        if ( $installer::globals::islinuxrpmbuild )
+        if ( $installer::globals::isrpmbuild )
+        {
+            $type = $type . "-rpm";
+        }
+
+        if ( $installer::globals::isdebbuild )
+        {
+            $type = $type . "-deb";
+        }
+
+        if ( $installer::globals::packageformat eq "archive" )
+        {
+            $type = $type . "-arc";
+        }
+    }
+    elsif ( $installer::globals::helppack )
+    {
+        $type = "helppack";
+
+        if ( $installer::globals::isrpmbuild )
         {
             $type = $type . "-rpm";
         }
         
-        if ( $installer::globals::islinuxdebbuild )
+        if ( $installer::globals::isdebbuild )
         {
             $type = $type . "-deb";
         }
@@ -676,12 +687,12 @@ sub get_install_type
     {
         $type = "install";
 
-        if ( $installer::globals::islinuxrpmbuild )
+        if ( $installer::globals::isrpmbuild )
         {
             $type = $type . "-rpm";
         }
         
-        if ( $installer::globals::islinuxdebbuild )
+        if ( $installer::globals::isdebbuild )
         {
             $type = $type . "-deb";
         }
@@ -709,7 +720,7 @@ sub get_downloadname_addon
 {
     my $addon = "";
 
-    if ( $installer::globals::islinuxdebbuild ) { $addon = $addon . "_deb"; }
+    if ( $installer::globals::isdebbuild ) { $addon = $addon . "_deb"; }
     
     if ( $installer::globals::product =~ /_wJRE\s*$/ ) { $addon = "_wJRE"; }
     
@@ -753,7 +764,6 @@ sub get_current_version
     my $infoline = "";
     my $versionstring = "";
     my $filename = "version.info";
-    # $filename = $installer::globals::ooouploaddir . $installer::globals::separator . $filename;
     
     if ( -f $filename )
     {
@@ -778,9 +788,7 @@ sub get_current_version
 ###############################################################################################
 # Setting the download file name
 # Syntax:
-# (PRODUCTNAME)_(VERSION)_(TIMESTAMP)_(OS)_(ARCH)_(INSTALLTYPE)_(LANGUAGE).(FILEEXTENSION)
-# Rules:
-# Timestamp only for Beta and Release Candidate
+# (PRODUCTNAME)_(VERSION)_(OS)_(ARCH)_(INSTALLTYPE)_(LANGUAGE).(FILEEXTENSION)
 ###############################################################################################
 
 sub set_download_filename
@@ -789,7 +797,6 @@ sub set_download_filename
     
     my $start = get_downloadname_productname($allvariables);
     my $versionstring = get_download_version($allvariables);
-    my $date = set_date_string($allvariables);
     my $platform = get_download_platformname();
     my $architecture = get_download_architecture();
     my $type = get_install_type($allvariables);
@@ -797,7 +804,7 @@ sub set_download_filename
     
     # Setting the extension happens automatically
 
-    my $filename = $start . "_" . $versionstring . "_" . $date . "_" . $platform . "_" . $architecture . "_" . $type . "_" . $language; 
+    my $filename = $start . "_" . $versionstring . "_" . "_" . $platform . "_" . $architecture . "_" . $type . "_" . $language;
     
     $filename =~ s/\_\_/\_/g;	# necessary, if $versionstring or $platform or $language are empty
     $filename =~ s/\_\s*$//;	# necessary, if $language and $addon are empty
@@ -986,46 +993,16 @@ sub put_windows_productname_into_template
 }
 
 ##################################################################
-# Windows: Including the path to the banner.bmp into nsi template 
+# Windows: Substituting the path to a file into the nsi template
 ##################################################################
 
-sub put_banner_bmp_into_template
+sub substitute_path_into_template
 {
-    my ($templatefile, $includepatharrayref, $allvariables) = @_;
-    
-    # my $filename = "downloadbanner.bmp";
-    if ( ! $allvariables->{'DOWNLOADBANNER'} ) { installer::exiter::exit_program("ERROR: DOWNLOADBANNER not defined in product definition!", "put_banner_bmp_into_template"); }
-    my $filename = $allvariables->{'DOWNLOADBANNER'};
+    my ($templatefile, $includepatharrayref, $allvariables, $var, $subst) = @_;
 
-    my $completefilenameref = "";
-
-    if ( $installer::globals::include_pathes_read )
-    {
-        $completefilenameref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$filename, $includepatharrayref, 0);		
-    }
-    else
-    {
-        $completefilenameref = installer::scriptitems::get_sourcepath_from_filename_and_includepath_classic(\$filename, $includepatharrayref, 0);
-    }
-
-    if ($$completefilenameref eq "") { installer::exiter::exit_program("ERROR: Could not find download file $filename!", "put_banner_bmp_into_template"); }
-
-    if ( $^O =~ /cygwin/i ) { $$completefilenameref =~ s/\//\\/g; }
-
-    replace_one_variable($templatefile, "BANNERBMPPLACEHOLDER", $$completefilenameref);
-}
-
-##################################################################
-# Windows: Including the path to the welcome.bmp into nsi template 
-##################################################################
-
-sub put_welcome_bmp_into_template
-{
-    my ($templatefile, $includepatharrayref, $allvariables) = @_;
-
-    # my $filename = "downloadbitmap.bmp";
-    if ( ! $allvariables->{'DOWNLOADBITMAP'} ) { installer::exiter::exit_program("ERROR: DOWNLOADBITMAP not defined in product definition!", "put_welcome_bmp_into_template"); }
-    my $filename = $allvariables->{'DOWNLOADBITMAP'};
+    if ( ! $allvariables->{$var} ) { $var =~ s/_.*$//; } # _BR suffix ?
+    if ( ! $allvariables->{$var} ) { installer::exiter::exit_program("ERROR: $var not defined in product definition!", "substitute_path_into_template"); }
+    my $filename = $allvariables->{$var};
 
     my $completefilenameref = "";
 
@@ -1038,95 +1015,24 @@ sub put_welcome_bmp_into_template
         $completefilenameref = installer::scriptitems::get_sourcepath_from_filename_and_includepath_classic(\$filename, $includepatharrayref, 0);
     }
 
-    if ($$completefilenameref eq "") { installer::exiter::exit_program("ERROR: Could not find download file $filename!", "put_welcome_bmp_into_template"); }
+    if ($$completefilenameref eq "") { installer::exiter::exit_program("ERROR: Could not find download file $filename!", "substitute_path_into_template"); }
 
     if ( $^O =~ /cygwin/i ) { $$completefilenameref =~ s/\//\\/g; }
 
-    replace_one_variable($templatefile, "WELCOMEBMPPLACEHOLDER", $$completefilenameref);
+    replace_one_variable($templatefile, $subst, $$completefilenameref);
 }
 
 ##################################################################
-# Windows: Including the path to the setup.ico into nsi template 
+# Windows: substitute a variable into the nsi template
 ##################################################################
-
-sub put_setup_ico_into_template
+sub substitute_variable_into_template($$$$)
 {
-    my ($templatefile, $includepatharrayref, $allvariables) = @_;
+    my ($templatefile, $variableshashref, $varname, $subst) = @_;
 
-    # my $filename = "downloadsetup.ico";
-    if ( ! $allvariables->{'DOWNLOADSETUPICO'} ) { installer::exiter::exit_program("ERROR: DOWNLOADSETUPICO not defined in product definition!", "put_setup_ico_into_template"); }
-    my $filename = $allvariables->{'DOWNLOADSETUPICO'};
+    my $var = "";
+    if ( $variableshashref->{$varname} ) { $var = $variableshashref->{$varname}; }
 
-    my $completefilenameref = "";
-
-    if ( $installer::globals::include_pathes_read )
-    {
-        $completefilenameref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$filename, $includepatharrayref, 0);
-    }
-    else
-    {
-        $completefilenameref = installer::scriptitems::get_sourcepath_from_filename_and_includepath_classic(\$filename, $includepatharrayref, 0);
-    }
-
-    if ($$completefilenameref eq "") { installer::exiter::exit_program("ERROR: Could not find download file $filename!", "put_setup_ico_into_template"); }
-
-    if ( $^O =~ /cygwin/i ) { $$completefilenameref =~ s/\//\\/g; }
-
-    replace_one_variable($templatefile, "SETUPICOPLACEHOLDER", $$completefilenameref);
-}
-
-##################################################################
-# Windows: Including the publisher into nsi template 
-##################################################################
-
-sub put_publisher_into_template
-{
-    my ($templatefile) = @_;
-    
-    my $publisher = "Sun Microsystems, Inc.";
-
-    replace_one_variable($templatefile, "PUBLISHERPLACEHOLDER", $publisher);
-}
-
-##################################################################
-# Windows: Including the web site into nsi template 
-##################################################################
-
-sub put_website_into_template
-{
-    my ($templatefile) = @_;
-
-    my $website = "http\:\/\/www\.sun\.com\/staroffice";
-
-    replace_one_variable($templatefile, "WEBSITEPLACEHOLDER", $website);
-}
-
-##################################################################
-# Windows: Including the Java file name into nsi template 
-##################################################################
-
-sub put_javafilename_into_template
-{
-    my ($templatefile, $variableshashref) = @_;
-    
-    my $javaversion = "";
-    
-    if ( $variableshashref->{'WINDOWSJAVAFILENAME'} ) { $javaversion = $variableshashref->{'WINDOWSJAVAFILENAME'}; }
-    
-    replace_one_variable($templatefile, "WINDOWSJAVAFILENAMEPLACEHOLDER", $javaversion);
-}
-
-##################################################################
-# Windows: Including the product version into nsi template 
-##################################################################
-
-sub put_windows_productversion_into_template
-{
-    my ($templatefile, $variableshashref) = @_;
-    
-    my $productversion = $variableshashref->{'PRODUCTVERSION'};
-    
-    replace_one_variable($templatefile, "PRODUCTVERSIONPLACEHOLDER", $productversion);
+    replace_one_variable($templatefile, $subst, $var);
 }
 
 ##################################################################
@@ -1141,8 +1047,7 @@ sub put_windows_productpath_into_template
     
     if (length($locallangs) > $installer::globals::max_lang_length) { $locallangs = "multi lingual"; }
 
-    if ( ! $installer::globals::languagepack ) { $productpath = $productpath . " (" . sprintf('%x', time()) . ")"; }
-    # if (( $installer::globals::languagepack ) && ( $installer::globals::unicodensis )) { $productpath = convert_textstring_to_utf16($productpath, $localnsisdir, "stringhelper.txt"); }
+    if ( ! $installer::globals::languagepack || ! $installer::globals::helppack ) { $productpath = $productpath . " (" . sprintf('%x', time()) . ")"; }
     
     replace_one_variable($templatefile, "PRODUCTPATHPLACEHOLDER", $productpath);
 }
@@ -1298,7 +1203,6 @@ sub nsis_language_converter
         my $infoline = "NSIS language_converter : Could not find nsis language for $language!\n";
         push( @installer::globals::logfileinfo, $infoline);
         $nsislanguage = "English";
-        # installer::exiter::exit_program("ERROR: Could not find nsis language for $language!", "nsis_language_converter");  
     }
 
     return $nsislanguage;
@@ -1527,8 +1431,6 @@ sub convert_utf16_to_utf8
     my $savfilename = $filename . "_before.utf16";
     installer::systemactions::copy_one_file($filename, $savfilename);
 
-#	open( IN, "<:utf16", $filename ) || installer::exiter::exit_program("ERROR: Cannot open file $filename for reading", "convert_utf16_to_utf8");
-#	open( IN, "<:para:crlf:uni", $filename ) || installer::exiter::exit_program("ERROR: Cannot open file $filename for reading", "convert_utf16_to_utf8");
     open( IN, "<:encoding(UTF16-LE)", $filename ) || installer::exiter::exit_program("ERROR: Cannot open file $filename for reading", "convert_utf16_to_utf8");
     while ( $line = <IN> ) {
         push @localfile, $line;
@@ -1753,12 +1655,6 @@ sub get_path_to_nsis_sdk
         $nsispath = $ENV{'NSISSDK_SOURCE'};	# overriding the NSIS SDK with NSISSDK_SOURCE
     }
 
-#	if( ($^O =~ /cygwin/i) and $nsispath =~ /\\/ ) {
-#		# We need a POSIX path for W32-4nt-cygwin-perl
-#		$nsispath =~ s/\\/\\\\/g;
-#		chomp( $nsispath = qx{cygpath -u "$nsispath"} );
-#	}
-
     if ( $nsispath eq "" )
     {
         installer::logger::print_message( "... no Environment variable \"SOLARROOT\", \"NSIS_PATH\" or \"NSISSDK_SOURCE\" found and NSIS not found in path!", "get_path_to_nsis_sdk");
@@ -1784,7 +1680,7 @@ sub call_nsis
 
     if( $^O =~ /cygwin/i ) { $nsifile =~ s/\\/\//g;	}
 
-    my $systemcall = "$makensisexe $nsifile |";
+    my $systemcall = "$makensisexe /V4 /DMUI_VERBOSE=4 $nsifile |";
 
     my $infoline = "Systemcall: $systemcall\n";
     push( @installer::globals::logfileinfo, $infoline);
@@ -1834,7 +1730,8 @@ sub replace_variables
 {
     my ($translationfile, $variableshashref) = @_;
 
-    foreach $key (keys %{$variableshashref})
+    # we want to substitute FOO_BR before FOO to avoid floating _BR suffixes
+    foreach $key (sort { length ($b) <=> length ($a) } keys %{$variableshashref})
     {
         my $value = $variableshashref->{$key};
 
@@ -1873,9 +1770,6 @@ sub remove_english_for_nsis_installer
 {
     my ($languagestringref, $languagesarrayref) = @_;
 
-    # $$languagestringref =~ s/en-US_//;
-    # shift(@{$languagesarrayref});
-
     @{$languagesarrayref} = ("en-US");	# only english for NSIS installer!
 }
 
@@ -1914,7 +1808,7 @@ sub is_supported_platform
 {
     my $is_supported = 0;
     
-    if (( $installer::globals::islinuxrpmbuild ) ||
+    if (( $installer::globals::isrpmbuild ) ||
         ( $installer::globals::issolarissparcbuild ) ||
         ( $installer::globals::issolarisx86build ) ||
         ( $installer::globals::iswindowsbuild ))
@@ -1951,7 +1845,7 @@ sub create_download_sets
     my $lastdir = $installationdir;
     installer::pathanalyzer::make_absolute_filename_to_relative_filename(\$lastdir);
 
-    if ( $lastdir =~ /\./ ) { $lastdir =~ s/\./_download_inprogress\./ }
+    if ( $installer::globals::iswindowsbuild && $lastdir =~ /\./ ) { $lastdir =~ s/\./_download_inprogress\./ }
     else { $lastdir = $lastdir . "_download_inprogress"; }
 
     # removing existing directory "_native_packed_inprogress" and "_native_packed_witherror" and "_native_packed"
@@ -2077,13 +1971,29 @@ sub create_download_sets
 
         # add product name into script template
         put_windows_productname_into_template($templatefile, $allvariableshashref);
-        put_banner_bmp_into_template($templatefile, $includepatharrayref, $allvariableshashref);
-        put_welcome_bmp_into_template($templatefile, $includepatharrayref, $allvariableshashref);
-        put_setup_ico_into_template($templatefile, $includepatharrayref, $allvariableshashref);
-        put_publisher_into_template($templatefile);
-        put_website_into_template($templatefile);
-        put_javafilename_into_template($templatefile, $allvariableshashref);
-        put_windows_productversion_into_template($templatefile, $allvariableshashref);
+        @path_substs = (
+            'DOWNLOADBANNER_BR' => 'BANNERBMPPLACEHOLDER_BR',
+            'DOWNLOADBITMAP_BR' => 'WELCOMEBMPPLACEHOLDER_BR',
+            'DOWNLOADBANNER' => 'BANNERBMPPLACEHOLDER',
+            'DOWNLOADBITMAP' => 'WELCOMEBMPPLACEHOLDER',
+            'DOWNLOADSETUPICO' => 'SETUPICOPLACEHOLDER'
+        );
+        while (@path_substs) {
+            my $var= shift @path_substs;
+            my $val = shift @path_substs;
+            substitute_path_into_template($templatefile, $includepatharrayref,
+                                          $allvariableshashref, $var, $val);
+        }
+        %var_substs = (
+            'OOOVENDOR' => 'PUBLISHERPLACEHOLDER',
+            'STARTCENTER_INFO_URL' => 'WEBSITEPLACEHOLDER',
+            'WINDOWSJAVAFILENAME' => 'WINDOWSJAVAFILENAMEPLACEHOLDER',
+            'PRODUCTVERSION' => 'PRODUCTVERSIONPLACEHOLDER'
+        );
+        for $var (keys %var_substs) {
+            substitute_variable_into_template($templatefile, $allvariableshashref,
+                                              $var, $var_substs{$var});
+        }
         put_windows_productpath_into_template($templatefile, $allvariableshashref, $languagestringref, $localnsisdir);
         put_outputfilename_into_template($templatefile, $downloadname);
         put_filelist_into_template($templatefile, $installationdir);
@@ -2153,9 +2063,6 @@ sub create_download_link_tree
                 push( @installer::globals::logfileinfo, $infoline);
 
                 create_link_tree($sourcedownloadfile, $destdownloadfilename, $versionstring);
-                # my $md5sumoutput = call_md5sum($downloadfile);
-                # my $md5sum = get_md5sum($md5sumoutput);
-                
             }
         }
         else
